@@ -1,6 +1,7 @@
 package backoff
 
 import (
+	"errors"
 	"math/rand"
 	"testing"
 	"time"
@@ -9,7 +10,7 @@ import (
 func TestMaxTriesHappy(t *testing.T) {
 	r := rand.New(rand.NewSource(time.Now().UnixNano()))
 	max := 17 + r.Intn(13)
-	bo := WithMaxTries(&ZeroBackOff{}, uint64(max))
+	bo := WithMaxRetries(&ZeroBackOff{}, uint64(max))
 
 	// Load up the tries count, but reset should clear the record
 	for ix := 0; ix < max/2; ix++ {
@@ -40,16 +41,23 @@ func TestMaxTriesHappy(t *testing.T) {
 	if d == Stop {
 		t.Error("returned Stop after reset")
 	}
-
 }
 
+// https://github.com/cenkalti/backoff/issues/80
 func TestMaxTriesZero(t *testing.T) {
-	// It might not make sense, but its okay to send a zero
-	bo := WithMaxTries(&ZeroBackOff{}, uint64(0))
-	for ix := 0; ix < 11; ix++ {
-		d := bo.NextBackOff()
-		if d == Stop {
-			t.Errorf("returned Stop on try %d", ix)
-		}
+	var called int
+
+	b := WithMaxRetries(&ZeroBackOff{}, 0)
+
+	err := Retry(func() error {
+		called++
+		return errors.New("err")
+	}, b)
+
+	if err == nil {
+		t.Errorf("error expected, nil founc")
+	}
+	if called != 1 {
+		t.Errorf("operation is called %d times", called)
 	}
 }
